Ontology Documentation generated by WIDOCO

language en

This version:
  https://celine-eu.github.io/ontologies/releases/v0.1
Publisher:
  CELINE Project
Imported Ontologies:
  time#
  time
  <http://www.w3.org/ns/sosa/>
  <https://saref.etsi.org/core/>
  <https://saref.etsi.org/saref4city/>
  <https://saref.etsi.org/saref4ener/>
  <https://w3id.org/pep/>
  ActorOntology
  ActorVocabulary
  ArchitectureOntology
  AreaOntology
  BuildingCategoriesVocabulary
  BuildingEnergyOntology
  BuildingLoadsOntology
  BuildingOntology
  ElectricPowerSystemVocabulary
  ElectricVehicleVocabulary
  ElectricityPlayerOntology
  EnergyFormVocabulary
  EnergyOntology
  EnergyUnitVocabulary
  EvaluationOntology
  FailableVocabulary
  FeatureOfInterestOntology
  FlexibilityVocabulary
  FourierVocabulary
  GeometryVocabulary
  GreenKPIVocabulary
  LightSystemOntology
  LightSystemVocabulary
  MarketOntology
  MonetaryVocabulary
  OperatingVocabulary
  PhotovoltaicOntology
  PhotovoltaicVocabulary
  StatisticsVocabulary
  SystemOntology
  TechnicalSystemOntology
  ThermodynamicSystemOntology
  ThermodynamicSystemVocabulary
  TimeSeriesOntology
  UpperOntology
  WeatherOntology
Download serialization:
License:
Cite as:
  Retrieved from: https://celine-eu.github.io/ontologies/releases/v0.1

Provenance of this page

Ontology Specification Draft

## Acknowledgments back to ToC

The authors would like to thank Silvio Peroni for developing LODE, a Live OWL Documentation Environment, which is used for representing the Cross Referencing Section of this document and Daniel Garijo for developing Widoco, the program used to create the template used in this documentation.